### Name: BTm
### Title: Bradley-Terry model and extensions
### Aliases: BTm drop1.BTm add1.BTm terms.BTm formula.BTm
### Keywords: models

### ** Examples

##
##  Statistics journal citation data from Stigler (1994)
##  -- see also Agresti (2002, p448)
data(citations)
                 
##  First fit the "standard" Bradley-Terry model
print(citeModel <- BTm(citations ~ ..))

##  Now the same thing with a different "reference" journal
update(citeModel, . ~ ., refcat = "JASA")

##  Is the "citeability" of a journal predicted by its country of origin?
origin <- factor(c("UK", "USA", "USA", "UK"))
print(citeModel2 <- BTm(citations ~ origin))

##  Hmm... not so sure about the origin of "Comm Statist" ...
is.na(origin[2]) <- TRUE
citeModel2 <- update(citeModel2, . ~ .)

##  Now an example with an order effect -- see Agresti (2002) p438
data(baseball)

##  Simple Bradley-Terry model as in Agresti p437
print(baseballModel <- BTm(baseball ~ ..))

##  Introduce order effect as in Agresti p438
update(baseballModel, order.effect = baseball$home.adv)   




